==> haskell-doctest-exitcode-stdio-0.0.0.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-exitcode-stdio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-exitcode-stdio
version:              0.0.0.1
visibility:           public
id:                   doctest-exitcode-stdio-0.0.0.1-Km3sBPYRjCeEuQc7GmixxB
key:                  doctest-exitcode-stdio-0.0.0.1-Km3sBPYRjCeEuQc7GmixxB
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             https://hub.darcs.net/thielema/doctest-exitcode-stdio/
synopsis:             Run doctest'\''s in a Cabal.Test.exitcode-stdio environment
description:
    Run doctest'\''s in a Cabal.Test.exitcode-stdio environment.
    For use with the @doctest-extract@ utility.
    Normally, you should not need to import a module from this package,
    only generated code will do this.

category:             Testing
abi:                  8c8b83a3144bc8297f91b15fbefcc786
exposed:              True
exposed-modules:      Test.DocTest.Driver
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/doctest-exitcode-stdio-0.0.0.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/doctest-exitcode-stdio-0.0.0.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/doctest-exitcode-stdio-0.0.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-exitcode-stdio
hs-libraries:         HSdoctest-exitcode-stdio-0.0.0.1-Km3sBPYRjCeEuQc7GmixxB
depends:
    QuickCheck-2.14.3-7hqZHxjEzJA3sWW6zgGwOZ base-4.17.2.1
    doctest-lib-0.1.1.1-4oRkoXytulaCTxFimQ6LNZ transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-doctest-exitcode-stdio/html/doctest-exitcode-stdio.haddock

haddock-html:         /usr/share/doc/haskell-doctest-exitcode-stdio/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-exitcode-stdio-0.0.0.1-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-exitcode-stdio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-exitcode-stdio
version:              0.0.0.1
visibility:           public
id:                   doctest-exitcode-stdio-0.0.0.1-DrDEWPRmObEJkQrN2kDqT2
key:                  doctest-exitcode-stdio-0.0.0.1-DrDEWPRmObEJkQrN2kDqT2
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             https://hub.darcs.net/thielema/doctest-exitcode-stdio/
synopsis:             Run doctest'\''s in a Cabal.Test.exitcode-stdio environment
description:
    Run doctest'\''s in a Cabal.Test.exitcode-stdio environment.
    For use with the @doctest-extract@ utility.
    Normally, you should not need to import a module from this package,
    only generated code will do this.

category:             Testing
abi:                  6c890adf3348043dc7ffc488f00088c9
exposed:              True
exposed-modules:      Test.DocTest.Driver
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/doctest-exitcode-stdio-0.0.0.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/doctest-exitcode-stdio-0.0.0.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/doctest-exitcode-stdio-0.0.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-exitcode-stdio
hs-libraries:         HSdoctest-exitcode-stdio-0.0.0.1-DrDEWPRmObEJkQrN2kDqT2
depends:
    QuickCheck-2.14.3-1roXk93057vCM76NaUaTTz base-4.17.2.1
    doctest-lib-0.1.1.1-4oRkoXytulaCTxFimQ6LNZ transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-doctest-exitcode-stdio/html/doctest-exitcode-stdio.haddock

haddock-html:         /usr/share/doc/haskell-doctest-exitcode-stdio/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
